aboutgitcodebugslistschat
path: root/tcp.h
diff options
context:
space:
mode:
Diffstat (limited to 'tcp.h')
-rw-r--r--tcp.h18
1 files changed, 12 insertions, 6 deletions
diff --git a/tcp.h b/tcp.h
index 6a9aa4a..52f4bb0 100644
--- a/tcp.h
+++ b/tcp.h
@@ -38,18 +38,24 @@ union tcp_epoll_ref {
* @hash_secret: 128-bit secret for hash functions, ISN and hash table
* @tap_conn_count: Count of tap connections in connection table
* @splice_conn_count: Count of spliced connections in connection table
* @port_to_tap: Ports bound host/init-side, packets to guest/tap
* @port_to_init: Ports bound namespace-side, spliced to init
* @port_to_ns: Ports bound init-side, spliced to namespace
* @timer_run: Timestamp of most recent timer run
*/
struct tcp_ctx {
uint64_t hash_secret[2];
int tap_conn_count;
int splice_conn_count;
- uint8_t port_to_tap [USHRT_MAX / 8];
- uint8_t port_to_init [USHRT_MAX / 8];
- uint8_t port_to_ns [USHRT_MAX / 8];
+ uint8_t port4_to_tap [USHRT_MAX / 8];
+ uint8_t port6_to_tap [USHRT_MAX / 8];
+ uint8_t port4_to_init [USHRT_MAX / 8];
+ uint8_t port6_to_init [USHRT_MAX / 8];
+ uint8_t port4_to_ns [USHRT_MAX / 8];
+ uint8_t port6_to_ns [USHRT_MAX / 8];
struct timespec timer_run;
};
@@ -38,18 +38,24 @@ union tcp_epoll_ref {
* @tap_conn_count: Count of tap connections in connection table
* @splice_conn_count: Count of spliced connections in connection table
- * @port_to_tap: Ports bound host/init-side, packets to guest/tap
- * @port_to_init: Ports bound namespace-side, spliced to init
- * @port_to_ns: Ports bound init-side, spliced to namespace
+ * @port4_to_tap: IPv4 ports bound host/init-side, packets to guest/tap
+ * @port6_to_tap: IPv6 ports bound host/init-side, packets to guest/tap
+ * @port4_to_init: IPv4 ports bound namespace-side, spliced to init
+ * @port6_to_init: IPv6 ports bound namespace-side, spliced to init
+ * @port4_to_ns: IPv4 ports bound init-side, spliced to namespace
+ * @port6_to_ns: IPv6 ports bound init-side, spliced to namespace
* @timer_run: Timestamp of most recent timer run
*/